# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/polvo/',
                'doc_host': 'https://lgvaz.github.io',
                'git_url': 'https://github.com/lgvaz/polvo/',
                'lib_path': 'polvo'},
  'syms': { 'polvo.bbox.core': { 'polvo.bbox.core.BBox': ('bbox.core.html#bbox', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core.BBox.__eq__': ('bbox.core.html#bbox.__eq__', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core.BBox.__repr__': ('bbox.core.html#bbox.__repr__', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core.BBox.accept_visit': ('bbox.core.html#bbox.accept_visit', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core.BBox.from_relative_xcycwh': ( 'bbox.core.html#bbox.from_relative_xcycwh',
                                                                                'polvo/bbox/core.py'),
                                 'polvo.bbox.core.BBox.from_rle': ('bbox.core.html#bbox.from_rle', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core.BBox.from_xycenter_wh': ('bbox.core.html#bbox.from_xycenter_wh', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core.BBox.from_xywh': ('bbox.core.html#bbox.from_xywh', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core.BBox.from_xyxy': ('bbox.core.html#bbox.from_xyxy', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core.BBox.normalized_xycenter_wh': ( 'bbox.core.html#bbox.normalized_xycenter_wh',
                                                                                  'polvo/bbox/core.py'),
                                 'polvo.bbox.core.BBox.relative_xcycwh': ('bbox.core.html#bbox.relative_xcycwh', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core.BBoxLabeled': ('bbox.core.html#bboxlabeled', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core.BBoxLabeled.accept_visit': ( 'bbox.core.html#bboxlabeled.accept_visit',
                                                                               'polvo/bbox/core.py'),
                                 'polvo.bbox.core.OBBox': ('bbox.core.html#obbox', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core.OBBox.__repr__': ('bbox.core.html#obbox.__repr__', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core.OBBox.accept_visit': ('bbox.core.html#obbox.accept_visit', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core.OBBox.from_clockwise': ('bbox.core.html#obbox.from_clockwise', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core.OBBoxLabeled': ('bbox.core.html#obboxlabeled', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core.OBBoxLabeled.accept_visit': ( 'bbox.core.html#obboxlabeled.accept_visit',
                                                                                'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox': ('bbox.core.html#_bbox', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.__init__': ('bbox.core.html#_bbox.__init__', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.area': ('bbox.core.html#_bbox.area', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.flat': ('bbox.core.html#_bbox.flat', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.from_flat': ('bbox.core.html#_bbox.from_flat', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.from_points': ('bbox.core.html#_bbox.from_points', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.height': ('bbox.core.html#_bbox.height', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.normalized_points': ( 'bbox.core.html#_bbox.normalized_points',
                                                                              'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.width': ('bbox.core.html#_bbox.width', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.xmax': ('bbox.core.html#_bbox.xmax', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.xmin': ('bbox.core.html#_bbox.xmin', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.xycenter_wh': ('bbox.core.html#_bbox.xycenter_wh', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.xywh': ('bbox.core.html#_bbox.xywh', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.xyxy': ('bbox.core.html#_bbox.xyxy', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.xyxyxyxy': ('bbox.core.html#_bbox.xyxyxyxy', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.ymax': ('bbox.core.html#_bbox.ymax', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.ymin': ('bbox.core.html#_bbox.ymin', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBox.yxyx': ('bbox.core.html#_bbox.yxyx', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBoxLabeled': ('bbox.core.html#_bboxlabeled', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBoxLabeled.__init__': ('bbox.core.html#_bboxlabeled.__init__', 'polvo/bbox/core.py'),
                                 'polvo.bbox.core._BBoxLabeled.__repr__': ('bbox.core.html#_bboxlabeled.__repr__', 'polvo/bbox/core.py')},
            'polvo.bbox.vis': { 'polvo.bbox.vis._default_font': ('bbox.vis.html#_default_font', 'polvo/bbox/vis.py'),
                                'polvo.bbox.vis._random_color': ('bbox.vis.html#_random_color', 'polvo/bbox/vis.py'),
                                'polvo.bbox.vis.overlay': ('bbox.vis.html#overlay', 'polvo/bbox/vis.py'),
                                'polvo.bbox.vis.overlay_bbox_labelled': ('bbox.vis.html#overlay_bbox_labelled', 'polvo/bbox/vis.py'),
                                'polvo.bbox.vis.overlay_label': ('bbox.vis.html#overlay_label', 'polvo/bbox/vis.py')},
            'polvo.classification.baseline.baseline': { 'polvo.classification.baseline.baseline.FastaiMetricWrapper': ( 'classification.baseline.baseline.html#fastaimetricwrapper',
                                                                                                                        'polvo/classification/baseline/baseline.py'),
                                                        'polvo.classification.baseline.baseline.FastaiMetricWrapper.__init__': ( 'classification.baseline.baseline.html#fastaimetricwrapper.__init__',
                                                                                                                                 'polvo/classification/baseline/baseline.py'),
                                                        'polvo.classification.baseline.baseline.FastaiMetricWrapper.accumulate': ( 'classification.baseline.baseline.html#fastaimetricwrapper.accumulate',
                                                                                                                                   'polvo/classification/baseline/baseline.py'),
                                                        'polvo.classification.baseline.baseline.calculate_metrics': ( 'classification.baseline.baseline.html#calculate_metrics',
                                                                                                                      'polvo/classification/baseline/baseline.py'),
                                                        'polvo.classification.baseline.baseline.fixed_probs': ( 'classification.baseline.baseline.html#fixed_probs',
                                                                                                                'polvo/classification/baseline/baseline.py'),
                                                        'polvo.classification.baseline.baseline.random_probs': ( 'classification.baseline.baseline.html#random_probs',
                                                                                                                 'polvo/classification/baseline/baseline.py')},
            'polvo.classification.explorer': { 'polvo.classification.explorer.DataExplorer': ( 'classification.explorer.html#dataexplorer',
                                                                                               'polvo/classification/explorer.py'),
                                               'polvo.classification.explorer.DataExplorer.__init__': ( 'classification.explorer.html#dataexplorer.__init__',
                                                                                                        'polvo/classification/explorer.py'),
                                               'polvo.classification.explorer.DataExplorer._group_y': ( 'classification.explorer.html#dataexplorer._group_y',
                                                                                                        'polvo/classification/explorer.py'),
                                               'polvo.classification.explorer.DataExplorer.most_common': ( 'classification.explorer.html#dataexplorer.most_common',
                                                                                                           'polvo/classification/explorer.py'),
                                               'polvo.classification.explorer.DataExplorer.show_label': ( 'classification.explorer.html#dataexplorer.show_label',
                                                                                                          'polvo/classification/explorer.py'),
                                               'polvo.classification.explorer.DataExplorer.show_label_id': ( 'classification.explorer.html#dataexplorer.show_label_id',
                                                                                                             'polvo/classification/explorer.py'),
                                               'polvo.classification.explorer.DataExplorer.show_most_common': ( 'classification.explorer.html#dataexplorer.show_most_common',
                                                                                                                'polvo/classification/explorer.py')},
            'polvo.converter.coco': { 'polvo.converter.coco.COCO': ('converter.coco.html#coco', 'polvo/converter/coco.py'),
                                      'polvo.converter.coco.COCO._add_categories': ( 'converter.coco.html#coco._add_categories',
                                                                                     'polvo/converter/coco.py'),
                                      'polvo.converter.coco.COCO._contour_to_annotation': ( 'converter.coco.html#coco._contour_to_annotation',
                                                                                            'polvo/converter/coco.py'),
                                      'polvo.converter.coco.COCO._initial_json': ( 'converter.coco.html#coco._initial_json',
                                                                                   'polvo/converter/coco.py'),
                                      'polvo.converter.coco.COCO._visit_bbox_labelled': ( 'converter.coco.html#coco._visit_bbox_labelled',
                                                                                          'polvo/converter/coco.py'),
                                      'polvo.converter.coco.COCO._visit_image_file': ( 'converter.coco.html#coco._visit_image_file',
                                                                                       'polvo/converter/coco.py'),
                                      'polvo.converter.coco.COCO._visit_obbox_labelled': ( 'converter.coco.html#coco._visit_obbox_labelled',
                                                                                           'polvo/converter/coco.py'),
                                      'polvo.converter.coco.COCO._visit_segmask': ( 'converter.coco.html#coco._visit_segmask',
                                                                                    'polvo/converter/coco.py'),
                                      'polvo.converter.coco.COCO.convert_record': ( 'converter.coco.html#coco.convert_record',
                                                                                    'polvo/converter/coco.py'),
                                      'polvo.converter.coco.COCO.convert_records': ( 'converter.coco.html#coco.convert_records',
                                                                                     'polvo/converter/coco.py'),
                                      'polvo.converter.coco.COCO.dataset_json': ( 'converter.coco.html#coco.dataset_json',
                                                                                  'polvo/converter/coco.py'),
                                      'polvo.converter.coco.COCO.record_json': ( 'converter.coco.html#coco.record_json',
                                                                                 'polvo/converter/coco.py')},
            'polvo.converter.yolo': { 'polvo.converter.yolo.YOLO': ('converter.yolo.html#yolo', 'polvo/converter/yolo.py'),
                                      'polvo.converter.yolo.YOLO._visit_bbox_labelled': ( 'converter.yolo.html#yolo._visit_bbox_labelled',
                                                                                          'polvo/converter/yolo.py'),
                                      'polvo.converter.yolo.YOLO._visit_image_file': ( 'converter.yolo.html#yolo._visit_image_file',
                                                                                       'polvo/converter/yolo.py'),
                                      'polvo.converter.yolo.YOLO.convert_dataset': ( 'converter.yolo.html#yolo.convert_dataset',
                                                                                     'polvo/converter/yolo.py'),
                                      'polvo.converter.yolo.YOLO.convert_record': ( 'converter.yolo.html#yolo.convert_record',
                                                                                    'polvo/converter/yolo.py'),
                                      'polvo.converter.yolo.YOLO.convert_records': ( 'converter.yolo.html#yolo.convert_records',
                                                                                     'polvo/converter/yolo.py'),
                                      'polvo.converter.yolo.YOLO.yolo_yaml': ( 'converter.yolo.html#yolo.yolo_yaml',
                                                                               'polvo/converter/yolo.py')},
            'polvo.data.core': { 'polvo.data.core.ClassMap': ('data.core.html#classmap', 'polvo/data/core.py'),
                                 'polvo.data.core.ClassMap.__init__': ('data.core.html#classmap.__init__', 'polvo/data/core.py'),
                                 'polvo.data.core.ClassMap.__len__': ('data.core.html#classmap.__len__', 'polvo/data/core.py'),
                                 'polvo.data.core.ClassMap.__repr__': ('data.core.html#classmap.__repr__', 'polvo/data/core.py'),
                                 'polvo.data.core.Component': ('data.core.html#component', 'polvo/data/core.py'),
                                 'polvo.data.core.Label': ('data.core.html#label', 'polvo/data/core.py'),
                                 'polvo.data.core.Label.__eq__': ('data.core.html#label.__eq__', 'polvo/data/core.py'),
                                 'polvo.data.core.Label.__hash__': ('data.core.html#label.__hash__', 'polvo/data/core.py'),
                                 'polvo.data.core.Label.__init__': ('data.core.html#label.__init__', 'polvo/data/core.py'),
                                 'polvo.data.core.Label.__repr__': ('data.core.html#label.__repr__', 'polvo/data/core.py'),
                                 'polvo.data.core.Metadata': ('data.core.html#metadata', 'polvo/data/core.py'),
                                 'polvo.data.core.Metadata.accept_visit': ('data.core.html#metadata.accept_visit', 'polvo/data/core.py')},
            'polvo.data.transforms': { 'polvo.data.transforms.AlignOrientation': ( 'data.transforms.html#alignorientation',
                                                                                   'polvo/data/transforms.py'),
                                       'polvo.data.transforms.AlignOrientation.__init__': ( 'data.transforms.html#alignorientation.__init__',
                                                                                            'polvo/data/transforms.py'),
                                       'polvo.data.transforms.AlignOrientation.reverse': ( 'data.transforms.html#alignorientation.reverse',
                                                                                           'polvo/data/transforms.py'),
                                       'polvo.data.transforms.AlignOrientation.transform': ( 'data.transforms.html#alignorientation.transform',
                                                                                             'polvo/data/transforms.py'),
                                       'polvo.data.transforms.np2pil': ('data.transforms.html#np2pil', 'polvo/data/transforms.py'),
                                       'polvo.data.transforms.pil2np': ('data.transforms.html#pil2np', 'polvo/data/transforms.py')},
            'polvo.datasets.download': { 'polvo.datasets.download.snacks_tiny': ( 'datasets.download.html#snacks_tiny',
                                                                                  'polvo/datasets/download.py')},
            'polvo.draw.pil_drawer': { 'polvo.draw.pil_drawer.PILDrawer': ('draw.pil_drawer.html#pildrawer', 'polvo/draw/pil_drawer.py'),
                                       'polvo.draw.pil_drawer.PILDrawer._visit_bbox': ( 'draw.pil_drawer.html#pildrawer._visit_bbox',
                                                                                        'polvo/draw/pil_drawer.py'),
                                       'polvo.draw.pil_drawer.PILDrawer._visit_bbox_labelled': ( 'draw.pil_drawer.html#pildrawer._visit_bbox_labelled',
                                                                                                 'polvo/draw/pil_drawer.py'),
                                       'polvo.draw.pil_drawer.PILDrawer._visit_image_arr': ( 'draw.pil_drawer.html#pildrawer._visit_image_arr',
                                                                                             'polvo/draw/pil_drawer.py'),
                                       'polvo.draw.pil_drawer.PILDrawer._visit_image_file': ( 'draw.pil_drawer.html#pildrawer._visit_image_file',
                                                                                              'polvo/draw/pil_drawer.py'),
                                       'polvo.draw.pil_drawer.PILDrawer._visit_image_pil': ( 'draw.pil_drawer.html#pildrawer._visit_image_pil',
                                                                                             'polvo/draw/pil_drawer.py'),
                                       'polvo.draw.pil_drawer.PILDrawer._visit_metadata': ( 'draw.pil_drawer.html#pildrawer._visit_metadata',
                                                                                            'polvo/draw/pil_drawer.py'),
                                       'polvo.draw.pil_drawer.PILDrawer._visit_obbox': ( 'draw.pil_drawer.html#pildrawer._visit_obbox',
                                                                                         'polvo/draw/pil_drawer.py'),
                                       'polvo.draw.pil_drawer.PILDrawer._visit_obbox_labelled': ( 'draw.pil_drawer.html#pildrawer._visit_obbox_labelled',
                                                                                                  'polvo/draw/pil_drawer.py'),
                                       'polvo.draw.pil_drawer.PILDrawer.draw': ( 'draw.pil_drawer.html#pildrawer.draw',
                                                                                 'polvo/draw/pil_drawer.py')},
            'polvo.keypoint.core': { 'polvo.keypoint.core.Keypoints': ('keypoint.core.html#keypoints', 'polvo/keypoint/core.py'),
                                     'polvo.keypoint.core.Keypoints.__init__': ( 'keypoint.core.html#keypoints.__init__',
                                                                                 'polvo/keypoint/core.py'),
                                     'polvo.keypoint.core.Keypoints.__repr__': ( 'keypoint.core.html#keypoints.__repr__',
                                                                                 'polvo/keypoint/core.py'),
                                     'polvo.keypoint.core.Keypoints.accept_visit': ( 'keypoint.core.html#keypoints.accept_visit',
                                                                                     'polvo/keypoint/core.py'),
                                     'polvo.keypoint.core.Keypoints.from_2d': ( 'keypoint.core.html#keypoints.from_2d',
                                                                                'polvo/keypoint/core.py'),
                                     'polvo.keypoint.core.Keypoints.from_flat': ( 'keypoint.core.html#keypoints.from_flat',
                                                                                  'polvo/keypoint/core.py'),
                                     'polvo.keypoint.core.Keypoints.normalized': ( 'keypoint.core.html#keypoints.normalized',
                                                                                   'polvo/keypoint/core.py'),
                                     'polvo.keypoint.core.Keypoints.xy_points': ( 'keypoint.core.html#keypoints.xy_points',
                                                                                  'polvo/keypoint/core.py')},
            'polvo.keypoint.vis': {'polvo.keypoint.vis.overlay': ('keypoints.vis.html#overlay', 'polvo/keypoint/vis.py')},
            'polvo.segmask.core': { 'polvo.segmask.core.Polygon': ('segmask.core.html#polygon', 'polvo/segmask/core.py'),
                                    'polvo.segmask.core.Polygon.__init__': ('segmask.core.html#polygon.__init__', 'polvo/segmask/core.py'),
                                    'polvo.segmask.core.Polygon.__repr__': ('segmask.core.html#polygon.__repr__', 'polvo/segmask/core.py'),
                                    'polvo.segmask.core.Polygon.from_flat': ( 'segmask.core.html#polygon.from_flat',
                                                                              'polvo/segmask/core.py'),
                                    'polvo.segmask.core.Polygon.from_xy': ('segmask.core.html#polygon.from_xy', 'polvo/segmask/core.py'),
                                    'polvo.segmask.core.Polygon.xy': ('segmask.core.html#polygon.xy', 'polvo/segmask/core.py'),
                                    'polvo.segmask.core.PolygonLabeled': ('segmask.core.html#polygonlabeled', 'polvo/segmask/core.py'),
                                    'polvo.segmask.core.PolygonLabeled.__init__': ( 'segmask.core.html#polygonlabeled.__init__',
                                                                                    'polvo/segmask/core.py'),
                                    'polvo.segmask.core.PolygonLabeled.__repr__': ( 'segmask.core.html#polygonlabeled.__repr__',
                                                                                    'polvo/segmask/core.py'),
                                    'polvo.segmask.core.SegMask': ('segmask.core.html#segmask', 'polvo/segmask/core.py'),
                                    'polvo.segmask.core.SegMask.__init__': ('segmask.core.html#segmask.__init__', 'polvo/segmask/core.py'),
                                    'polvo.segmask.core.SegMask.__repr__': ('segmask.core.html#segmask.__repr__', 'polvo/segmask/core.py'),
                                    'polvo.segmask.core.SegMask.accept_visit': ( 'segmask.core.html#segmask.accept_visit',
                                                                                 'polvo/segmask/core.py'),
                                    'polvo.segmask.core.SegMask.from_polygons': ( 'segmask.core.html#segmask.from_polygons',
                                                                                  'polvo/segmask/core.py'),
                                    'polvo.segmask.core.SegMask.show': ('segmask.core.html#segmask.show', 'polvo/segmask/core.py'),
                                    'polvo.segmask.core.SegMask.to_contours': ( 'segmask.core.html#segmask.to_contours',
                                                                                'polvo/segmask/core.py'),
                                    'polvo.segmask.core.SegMask.to_polygons': ( 'segmask.core.html#segmask.to_polygons',
                                                                                'polvo/segmask/core.py')},
            'polvo.segmask.vis': { 'polvo.segmask.vis.overlay': ('segmask.vis.html#overlay', 'polvo/segmask/vis.py'),
                                   'polvo.segmask.vis.overlay_array': ('segmask.vis.html#overlay_array', 'polvo/segmask/vis.py')},
            'polvo.segmentation.vis': { 'polvo.segmentation.vis.overlay_mask': ( 'segmentation.vis.html#overlay_mask',
                                                                                 'polvo/segmentation/vis.py')},
            'polvo.test': {},
            'polvo.utils.download': { 'polvo.utils.download.download': ('utils.download.html#download', 'polvo/utils/download.py'),
                                      'polvo.utils.download.download_and_extract': ( 'utils.download.html#download_and_extract',
                                                                                     'polvo/utils/download.py'),
                                      'polvo.utils.download.download_and_extract_gdrive': ( 'utils.download.html#download_and_extract_gdrive',
                                                                                            'polvo/utils/download.py'),
                                      'polvo.utils.download.download_gdrive': ( 'utils.download.html#download_gdrive',
                                                                                'polvo/utils/download.py'),
                                      'polvo.utils.download.open_image_url': ( 'utils.download.html#open_image_url',
                                                                               'polvo/utils/download.py')},
            'polvo.utils.image_size': { 'polvo.utils.image_size.Image': ('utils.image_size.html#image', 'polvo/utils/image_size.py'),
                                        'polvo.utils.image_size.Image.to_str_json': ( 'utils.image_size.html#image.to_str_json',
                                                                                      'polvo/utils/image_size.py'),
                                        'polvo.utils.image_size.Image.to_str_row': ( 'utils.image_size.html#image.to_str_row',
                                                                                     'polvo/utils/image_size.py'),
                                        'polvo.utils.image_size.Image.to_str_row_verbose': ( 'utils.image_size.html#image.to_str_row_verbose',
                                                                                             'polvo/utils/image_size.py'),
                                        'polvo.utils.image_size.UnknownImageFormat': ( 'utils.image_size.html#unknownimageformat',
                                                                                       'polvo/utils/image_size.py'),
                                        'polvo.utils.image_size.get_image_metadata': ( 'utils.image_size.html#get_image_metadata',
                                                                                       'polvo/utils/image_size.py'),
                                        'polvo.utils.image_size.get_image_metadata_from_bytesio': ( 'utils.image_size.html#get_image_metadata_from_bytesio',
                                                                                                    'polvo/utils/image_size.py'),
                                        'polvo.utils.image_size.image_size': ( 'utils.image_size.html#image_size',
                                                                               'polvo/utils/image_size.py'),
                                        'polvo.utils.image_size.image_size_from_bytesio': ( 'utils.image_size.html#image_size_from_bytesio',
                                                                                            'polvo/utils/image_size.py')},
            'polvo.utils.io': { 'polvo.utils.io.ImageArr': ('utils.io.html#imagearr', 'polvo/utils/io.py'),
                                'polvo.utils.io.ImageArr.__init__': ('utils.io.html#imagearr.__init__', 'polvo/utils/io.py'),
                                'polvo.utils.io.ImageArr.accept_visit': ('utils.io.html#imagearr.accept_visit', 'polvo/utils/io.py'),
                                'polvo.utils.io.ImageArr.draw': ('utils.io.html#imagearr.draw', 'polvo/utils/io.py'),
                                'polvo.utils.io.ImageFile': ('utils.io.html#imagefile', 'polvo/utils/io.py'),
                                'polvo.utils.io.ImageFile.__new__': ('utils.io.html#imagefile.__new__', 'polvo/utils/io.py'),
                                'polvo.utils.io.ImageFile.accept_visit': ('utils.io.html#imagefile.accept_visit', 'polvo/utils/io.py'),
                                'polvo.utils.io.ImageFile.draw': ('utils.io.html#imagefile.draw', 'polvo/utils/io.py'),
                                'polvo.utils.io.ImageFile.open': ('utils.io.html#imagefile.open', 'polvo/utils/io.py'),
                                'polvo.utils.io.ImagePIL': ('utils.io.html#imagepil', 'polvo/utils/io.py'),
                                'polvo.utils.io.ImagePIL.__init__': ('utils.io.html#imagepil.__init__', 'polvo/utils/io.py'),
                                'polvo.utils.io.ImagePIL.accept_visit': ('utils.io.html#imagepil.accept_visit', 'polvo/utils/io.py'),
                                'polvo.utils.io.ImagePIL.draw': ('utils.io.html#imagepil.draw', 'polvo/utils/io.py'),
                                'polvo.utils.io.RenderDict': ('utils.io.html#renderdict', 'polvo/utils/io.py'),
                                'polvo.utils.io.RenderDict.__init__': ('utils.io.html#renderdict.__init__', 'polvo/utils/io.py'),
                                'polvo.utils.io.RenderDict._ipython_display_': ( 'utils.io.html#renderdict._ipython_display_',
                                                                                 'polvo/utils/io.py'),
                                'polvo.utils.io._get_files': ('utils.io.html#_get_files', 'polvo/utils/io.py'),
                                'polvo.utils.io.extract_files': ('utils.io.html#extract_files', 'polvo/utils/io.py'),
                                'polvo.utils.io.get_files': ('utils.io.html#get_files', 'polvo/utils/io.py'),
                                'polvo.utils.io.get_image_files': ('utils.io.html#get_image_files', 'polvo/utils/io.py'),
                                'polvo.utils.io.glob_match': ('utils.io.html#glob_match', 'polvo/utils/io.py'),
                                'polvo.utils.io.mkdir': ('utils.io.html#mkdir', 'polvo/utils/io.py'),
                                'polvo.utils.io.open_dill': ('utils.io.html#open_dill', 'polvo/utils/io.py'),
                                'polvo.utils.io.open_image': ('utils.io.html#open_image', 'polvo/utils/io.py'),
                                'polvo.utils.io.open_json': ('utils.io.html#open_json', 'polvo/utils/io.py'),
                                'polvo.utils.io.open_mask': ('utils.io.html#open_mask', 'polvo/utils/io.py'),
                                'polvo.utils.io.open_pickle': ('utils.io.html#open_pickle', 'polvo/utils/io.py'),
                                'polvo.utils.io.open_txt': ('utils.io.html#open_txt', 'polvo/utils/io.py'),
                                'polvo.utils.io.save_dill': ('utils.io.html#save_dill', 'polvo/utils/io.py'),
                                'polvo.utils.io.save_image': ('utils.io.html#save_image', 'polvo/utils/io.py'),
                                'polvo.utils.io.save_json': ('utils.io.html#save_json', 'polvo/utils/io.py'),
                                'polvo.utils.io.save_pickle': ('utils.io.html#save_pickle', 'polvo/utils/io.py'),
                                'polvo.utils.io.save_txt': ('utils.io.html#save_txt', 'polvo/utils/io.py')},
            'polvo.utils.logging': {'polvo.utils.logging.pbar': ('utils.logging.html#pbar', 'polvo/utils/logging.py')},
            'polvo.utils.misc': { 'polvo.utils.misc.Cache': ('utils.misc.html#cache', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.Cache.__init__': ('utils.misc.html#cache.__init__', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.Cache.get': ('utils.misc.html#cache.get', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.Cache.list_cached': ('utils.misc.html#cache.list_cached', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.flatten': ('utils.misc.html#flatten', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.kwargs_grid': ('utils.misc.html#kwargs_grid', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.partial': ('utils.misc.html#partial', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.partial.__call__': ('utils.misc.html#partial.__call__', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.partial.__init__': ('utils.misc.html#partial.__init__', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.partial.__repr__': ('utils.misc.html#partial.__repr__', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.partial.__str__': ('utils.misc.html#partial.__str__', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.random_color': ('utils.misc.html#random_color', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.random_local_seed': ('utils.misc.html#random_local_seed', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.safe_zip': ('utils.misc.html#safe_zip', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.skip_error': ('utils.misc.html#skip_error', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.skip_error.__call__': ('utils.misc.html#skip_error.__call__', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.skip_error.__init__': ('utils.misc.html#skip_error.__init__', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.sort_quadrilateral': ('utils.misc.html#sort_quadrilateral', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.transparent_cmap': ('utils.misc.html#transparent_cmap', 'polvo/utils/misc.py')},
            'polvo.utils.script': { 'polvo.utils.script.call_parse': ('utils.script.html#call_parse', 'polvo/utils/script.py'),
                                    'polvo.utils.script.test_script': ('utils.script.html#test_script', 'polvo/utils/script.py')},
            'polvo.utils.splits': { 'polvo.utils.splits.from_fn': ('utils.splits.html#from_fn', 'polvo/utils/splits.py'),
                                    'polvo.utils.splits.random': ('utils.splits.html#random', 'polvo/utils/splits.py')},
            'polvo.utils.visualization': { 'polvo.utils.visualization.get_grid': ( 'utils.visualization.html#get_grid',
                                                                                   'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.get_image_grid': ( 'utils.visualization.html#get_image_grid',
                                                                                         'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.grid_from_sequence': ( 'utils.visualization.html#grid_from_sequence',
                                                                                             'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.image_grid': ( 'utils.visualization.html#image_grid',
                                                                                     'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.image_size': ( 'utils.visualization.html#image_size',
                                                                                     'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.image_sizes_hist': ( 'utils.visualization.html#image_sizes_hist',
                                                                                           'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.normalize_axes': ( 'utils.visualization.html#normalize_axes',
                                                                                         'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.plot_grid': ( 'utils.visualization.html#plot_grid',
                                                                                    'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.show_grid': ( 'utils.visualization.html#show_grid',
                                                                                    'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.show_image': ( 'utils.visualization.html#show_image',
                                                                                     'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.show_images': ( 'utils.visualization.html#show_images',
                                                                                      'polvo/utils/visualization.py')},
            'polvo.utils.wandb': { 'polvo.utils.wandb.WandbRun': ('utils.wandb.html#wandbrun', 'polvo/utils/wandb.py'),
                                   'polvo.utils.wandb.WandbRun.__enter__': ('utils.wandb.html#wandbrun.__enter__', 'polvo/utils/wandb.py'),
                                   'polvo.utils.wandb.WandbRun.__exit__': ('utils.wandb.html#wandbrun.__exit__', 'polvo/utils/wandb.py'),
                                   'polvo.utils.wandb.WandbRun.__init__': ('utils.wandb.html#wandbrun.__init__', 'polvo/utils/wandb.py'),
                                   'polvo.utils.wandb.wandb_upload': ('utils.wandb.html#wandb_upload', 'polvo/utils/wandb.py')},
            'polvo.visitor.core': { 'polvo.visitor.core.Visitor': ('visitor.core.html#visitor', 'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor._visit_bbox': ( 'visitor.core.html#visitor._visit_bbox',
                                                                                'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor._visit_bbox_labelled': ( 'visitor.core.html#visitor._visit_bbox_labelled',
                                                                                         'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor._visit_image_arr': ( 'visitor.core.html#visitor._visit_image_arr',
                                                                                     'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor._visit_image_file': ( 'visitor.core.html#visitor._visit_image_file',
                                                                                      'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor._visit_image_pil': ( 'visitor.core.html#visitor._visit_image_pil',
                                                                                     'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor._visit_keypoints': ( 'visitor.core.html#visitor._visit_keypoints',
                                                                                     'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor._visit_metadata': ( 'visitor.core.html#visitor._visit_metadata',
                                                                                    'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor._visit_obbox': ( 'visitor.core.html#visitor._visit_obbox',
                                                                                 'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor._visit_obbox_labelled': ( 'visitor.core.html#visitor._visit_obbox_labelled',
                                                                                          'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor._visit_segmask': ( 'visitor.core.html#visitor._visit_segmask',
                                                                                   'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor.collect_accept_fns': ( 'visitor.core.html#visitor.collect_accept_fns',
                                                                                       'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor.execute_accept_fns': ( 'visitor.core.html#visitor.execute_accept_fns',
                                                                                       'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor.visit_all': ( 'visitor.core.html#visitor.visit_all',
                                                                              'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor.visit_bbox': ( 'visitor.core.html#visitor.visit_bbox',
                                                                               'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor.visit_bbox_labelled': ( 'visitor.core.html#visitor.visit_bbox_labelled',
                                                                                        'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor.visit_image_arr': ( 'visitor.core.html#visitor.visit_image_arr',
                                                                                    'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor.visit_image_file': ( 'visitor.core.html#visitor.visit_image_file',
                                                                                     'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor.visit_image_pil': ( 'visitor.core.html#visitor.visit_image_pil',
                                                                                    'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor.visit_keypoints': ( 'visitor.core.html#visitor.visit_keypoints',
                                                                                    'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor.visit_metadata': ( 'visitor.core.html#visitor.visit_metadata',
                                                                                   'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor.visit_obbox': ( 'visitor.core.html#visitor.visit_obbox',
                                                                                'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor.visit_obbox_labelled': ( 'visitor.core.html#visitor.visit_obbox_labelled',
                                                                                         'polvo/visitor/core.py'),
                                    'polvo.visitor.core.Visitor.visit_segmask': ( 'visitor.core.html#visitor.visit_segmask',
                                                                                  'polvo/visitor/core.py')}}}
